summaryrefslogtreecommitdiffstats
path: root/kooka
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commite7366c97c998679efa80cf61c88e64a11a3d3c33 (patch)
treea161d2940165f6cc47c05f0271ad8e5f64ffe6e8 /kooka
parentda4be7880ff1de6415ab6256afd2514e64f5fa2e (diff)
downloadtdegraphics-e7366c97c998679efa80cf61c88e64a11a3d3c33.tar.gz
tdegraphics-e7366c97c998679efa80cf61c88e64a11a3d3c33.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdegraphics@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kooka')
-rw-r--r--kooka/dwmenuaction.cpp4
-rw-r--r--kooka/dwmenuaction.h2
-rw-r--r--kooka/imageselectline.cpp4
-rw-r--r--kooka/imageselectline.h2
-rw-r--r--kooka/img_saver.cpp14
-rw-r--r--kooka/img_saver.h6
-rw-r--r--kooka/imgnamecombo.cpp4
-rw-r--r--kooka/imgprintdialog.cpp4
-rw-r--r--kooka/imgprintdialog.h2
-rw-r--r--kooka/kocrbase.cpp8
-rw-r--r--kooka/kocrgocr.cpp4
-rw-r--r--kooka/kocrkadmos.cpp4
-rw-r--r--kooka/kocrocrad.cpp4
-rw-r--r--kooka/kookaimage.cpp8
-rw-r--r--kooka/kookaimage.h8
-rw-r--r--kooka/kookapref.cpp6
-rw-r--r--kooka/kookarc30
-rw-r--r--kooka/kookaview.cpp24
-rw-r--r--kooka/kookaview.h2
-rw-r--r--kooka/ksaneocr.cpp10
-rw-r--r--kooka/ksaneocr.h2
-rw-r--r--kooka/ocrresedit.cpp4
-rw-r--r--kooka/ocrresedit.h2
-rw-r--r--kooka/scanpackager.cpp14
-rw-r--r--kooka/scanpackager.h4
-rw-r--r--kooka/thumbview.cpp8
-rw-r--r--kooka/thumbview.h2
-rw-r--r--kooka/thumbviewitem.cpp4
-rw-r--r--kooka/thumbviewitem.h2
29 files changed, 96 insertions, 96 deletions
diff --git a/kooka/dwmenuaction.cpp b/kooka/dwmenuaction.cpp
index d77c8d16..da0cee48 100644
--- a/kooka/dwmenuaction.cpp
+++ b/kooka/dwmenuaction.cpp
@@ -32,9 +32,9 @@
//-------------------------------------
dwMenuAction::dwMenuAction( const TQString& text, const KShortcut& cut,
- KDockWidget *dw,TQObject* tqparent,
+ KDockWidget *dw,TQObject* parent,
KDockMainWindow *mw, const char* name )
- :KToggleAction(text,cut,tqparent,name),m_dw(dw),m_mw(mw)
+ :KToggleAction(text,cut,parent,name),m_dw(dw),m_mw(mw)
{
connect(this,TQT_SIGNAL(toggled(bool)),this,TQT_SLOT(slotToggled(bool)));
connect(m_dw->dockManager(),TQT_SIGNAL(change()),this,TQT_SLOT(anDWChanged()));
diff --git a/kooka/dwmenuaction.h b/kooka/dwmenuaction.h
index d6cac229..958ebe82 100644
--- a/kooka/dwmenuaction.h
+++ b/kooka/dwmenuaction.h
@@ -47,7 +47,7 @@ class dwMenuAction:public KToggleAction
public:
dwMenuAction( const TQString& text,
const KShortcut& cut = KShortcut(),
- KDockWidget *dw=0, TQObject* tqparent = 0,
+ KDockWidget *dw=0, TQObject* parent = 0,
KDockMainWindow * mw=0, const char* name = 0 );
virtual ~dwMenuAction();
diff --git a/kooka/imageselectline.cpp b/kooka/imageselectline.cpp
index 99ba935e..a21b56c0 100644
--- a/kooka/imageselectline.cpp
+++ b/kooka/imageselectline.cpp
@@ -47,8 +47,8 @@
* together in a row. The button opens a file selector box to pick a file.
*/
-ImageSelectLine::ImageSelectLine( TQWidget *tqparent, const TQString& text )
- : TQHBox( tqparent )
+ImageSelectLine::ImageSelectLine( TQWidget *parent, const TQString& text )
+ : TQHBox( parent )
{
setSpacing( 5 );
(void) new TQLabel( text, this );
diff --git a/kooka/imageselectline.h b/kooka/imageselectline.h
index a9672edf..c3baae29 100644
--- a/kooka/imageselectline.h
+++ b/kooka/imageselectline.h
@@ -45,7 +45,7 @@ class ImageSelectLine:public TQHBox
Q_OBJECT
TQ_OBJECT
public:
- ImageSelectLine( TQWidget *tqparent, const TQString& text );
+ ImageSelectLine( TQWidget *parent, const TQString& text );
KURL selectedURL() const;
void setURL( const KURL& );
diff --git a/kooka/img_saver.h b/kooka/img_saver.h
index 31f6d8ab..0f9a713a 100644
--- a/kooka/img_saver.h
+++ b/kooka/img_saver.h
@@ -103,7 +103,7 @@ class FormatDialog:public KDialogBase
Q_OBJECT
TQ_OBJECT
public:
- FormatDialog( TQWidget *tqparent, const TQString&, const char * );
+ FormatDialog( TQWidget *parent, const TQString&, const char * );
TQString getFormat( ) const;
@@ -155,8 +155,8 @@ public:
* @param dir Name of the save root directory
* @param name Name of a subdirectory in the saveroot.
**/
- ImgSaver( TQWidget *tqparent, const KURL );
- ImgSaver( TQWidget *tqparent );
+ ImgSaver( TQWidget *parent, const KURL );
+ ImgSaver( TQWidget *parent );
TQString errorString( ImgSaveStat );
/**
diff --git a/kooka/imgnamecombo.cpp b/kooka/imgnamecombo.cpp
index 5205f1b1..8190d5bc 100644
--- a/kooka/imgnamecombo.cpp
+++ b/kooka/imgnamecombo.cpp
@@ -38,8 +38,8 @@
#include "imgnamecombo.h"
#include "img_saver.h"
-ImageNameCombo::ImageNameCombo( TQWidget *tqparent )
- : KComboBox( tqparent )
+ImageNameCombo::ImageNameCombo( TQWidget *parent )
+ : KComboBox( parent )
{
setInsertionPolicy( TQComboBox::AtTop );
}
diff --git a/kooka/imgprintdialog.cpp b/kooka/imgprintdialog.cpp
index 98a783f4..e79c92df 100644
--- a/kooka/imgprintdialog.cpp
+++ b/kooka/imgprintdialog.cpp
@@ -47,8 +47,8 @@
#define ID_CUSTOM 2
#define ID_FIT_PAGE 3
-ImgPrintDialog::ImgPrintDialog( KookaImage *img, TQWidget *tqparent, const char* name )
- : KPrintDialogPage( tqparent, name ),
+ImgPrintDialog::ImgPrintDialog( KookaImage *img, TQWidget *parent, const char* name )
+ : KPrintDialogPage( parent, name ),
m_image(img),
m_ignoreSignal(false)
{
diff --git a/kooka/imgprintdialog.h b/kooka/imgprintdialog.h
index 389a546c..3176afb8 100644
--- a/kooka/imgprintdialog.h
+++ b/kooka/imgprintdialog.h
@@ -55,7 +55,7 @@ class ImgPrintDialog: public KPrintDialogPage
Q_OBJECT
TQ_OBJECT
public:
- ImgPrintDialog( KookaImage *img, TQWidget *tqparent=0L, const char* name=0L );
+ ImgPrintDialog( KookaImage *img, TQWidget *parent=0L, const char* name=0L );
void setOptions(const TQMap<TQString,TQString>& opts);
void getOptions(TQMap<TQString,TQString>& opts, bool include_def = false);
diff --git a/kooka/kocrbase.cpp b/kooka/kocrbase.cpp
index 4c9ccc14..2cd5d20b 100644
--- a/kooka/kocrbase.cpp
+++ b/kooka/kocrbase.cpp
@@ -59,10 +59,10 @@
#include <tqgroupbox.h>
#include <tqcheckbox.h>
-KOCRBase::KOCRBase( TQWidget *tqparent, KSpellConfig *spellConfig,
+KOCRBase::KOCRBase( TQWidget *parent, KSpellConfig *spellConfig,
KDialogBase::DialogType face )
:KDialogBase( face, i18n("Optical Character Recognition"),
- User2|Close|User1, User1, tqparent,0, false, true,
+ User2|Close|User1, User1, parent,0, false, true,
KGuiItem( i18n("Start OCR" ), "launch",
i18n("Start the Optical Character Recognition process" )),
KGuiItem( i18n("Cancel" ), "stopocr",
@@ -98,11 +98,11 @@ KOCRBase::KOCRBase( TQWidget *tqparent, KSpellConfig *spellConfig,
}
-KAnimWidget* KOCRBase::getAnimation(TQWidget *tqparent)
+KAnimWidget* KOCRBase::getAnimation(TQWidget *parent)
{
if( ! m_animation )
{
- m_animation = new KAnimWidget( TQString("kde"), 48, tqparent, "ANIMATION" );
+ m_animation = new KAnimWidget( TQString("kde"), 48, parent, "ANIMATION" );
}
return( m_animation );
}
diff --git a/kooka/kocrgocr.cpp b/kooka/kocrgocr.cpp
index dbb255c4..ca913f1d 100644
--- a/kooka/kocrgocr.cpp
+++ b/kooka/kocrgocr.cpp
@@ -58,8 +58,8 @@
-KGOCRDialog::KGOCRDialog( TQWidget *tqparent, KSpellConfig *spellConfig )
- :KOCRBase( tqparent, spellConfig, KDialogBase::Tabbed ),
+KGOCRDialog::KGOCRDialog( TQWidget *parent, KSpellConfig *spellConfig )
+ :KOCRBase( parent, spellConfig, KDialogBase::Tabbed ),
m_ocrCmd( TQString())
{
kdDebug(28000) << "Starting KOCR-Start-Dialog!" << endl;
diff --git a/kooka/kocrkadmos.cpp b/kooka/kocrkadmos.cpp
index 99f86a4f..59afa1a4 100644
--- a/kooka/kocrkadmos.cpp
+++ b/kooka/kocrkadmos.cpp
@@ -64,8 +64,8 @@
#define CNTRY_CZ i18n( "Czech Republic, Slovakia")
#define CNTRY_GB i18n( "Great Britain, USA" )
-KadmosDialog::KadmosDialog( TQWidget *tqparent, KSpellConfig *spellConfig )
- :KOCRBase( tqparent, spellConfig, KDialogBase::Tabbed ),
+KadmosDialog::KadmosDialog( TQWidget *parent, KSpellConfig *spellConfig )
+ :KOCRBase( parent, spellConfig, KDialogBase::Tabbed ),
m_cbNoise(0),
m_cbAutoscale(0),
m_haveNorm(false)
diff --git a/kooka/kocrocrad.cpp b/kooka/kocrocrad.cpp
index ff675231..b9365767 100644
--- a/kooka/kocrocrad.cpp
+++ b/kooka/kocrocrad.cpp
@@ -54,8 +54,8 @@
-ocradDialog::ocradDialog( TQWidget *tqparent, KSpellConfig *spellConfig )
- :KOCRBase( tqparent, spellConfig, KDialogBase::Tabbed ),
+ocradDialog::ocradDialog( TQWidget *parent, KSpellConfig *spellConfig )
+ :KOCRBase( parent, spellConfig, KDialogBase::Tabbed ),
m_ocrCmd( TQString()),
m_orfUrlRequester(0L),
m_layoutMode(0),
diff --git a/kooka/kookaimage.cpp b/kooka/kookaimage.cpp
index 4bf7976c..ab491429 100644
--- a/kooka/kookaimage.cpp
+++ b/kooka/kookaimage.cpp
@@ -205,15 +205,15 @@ void KookaImage::extractNow()
{
kdDebug(28000) << "extracting a subimage number " << m_subNo << endl;
- KookaImage *tqparent = parentImage();
+ KookaImage *parent = parentImage();
- if( tqparent )
+ if( parent )
{
- loadTiffDir( tqparent->localFileName(), m_subNo );
+ loadTiffDir( parent->localFileName(), m_subNo );
}
else
{
- kdDebug(28000) << "ERR: No tqparent defined - can not laod subimage" << endl;
+ kdDebug(28000) << "ERR: No parent defined - can not laod subimage" << endl;
}
}
diff --git a/kooka/kookaimage.h b/kooka/kookaimage.h
index 559f1469..b56c086b 100644
--- a/kooka/kookaimage.h
+++ b/kooka/kookaimage.h
@@ -53,9 +53,9 @@ public:
KookaImage( );
/**
- * creating a subimage for a tqparent image.
+ * creating a subimage for a parent image.
* @param subNo contains the sequence number of subimages to create.
- * @param p is the tqparent image.
+ * @param p is the parent image.
*/
KookaImage( int subNo, KookaImage *p );
KookaImage( const TQImage& img );
@@ -76,7 +76,7 @@ public:
int subImagesCount() const;
/**
- * the tqparent image.
+ * the parent image.
*/
KookaImage* parentImage() const;
@@ -144,7 +144,7 @@ private:
bool loadTiffDir( const TQString&, int );
/* if subNo is 0, the image is the one and only. If it is larger than 0, the
- * tqparent contains the filename */
+ * parent contains the filename */
int m_subNo;
/* In case being a subimage */
diff --git a/kooka/kookapref.cpp b/kooka/kookapref.cpp
index 49271414..bebd60fa 100644
--- a/kooka/kookapref.cpp
+++ b/kooka/kookapref.cpp
@@ -176,12 +176,12 @@ void KookaPreferences::setupOCRPage()
}
}
-KURLRequester* KookaPreferences::binaryCheckBox( TQWidget *tqparent, const TQString& program )
+KURLRequester* KookaPreferences::binaryCheckBox( TQWidget *parent, const TQString& program )
{
- TQHBox *hbox = new TQHBox( tqparent );
+ TQHBox *hbox = new TQHBox( parent );
(void) new TQLabel( i18n("Select the %1 binary to use:").tqarg( program ), hbox );
- KURLRequester* urlRequester = new KURLRequester( tqparent );
+ KURLRequester* urlRequester = new KURLRequester( parent );
urlRequester->setMode( KFile::File | KFile::ExistingOnly | KFile::LocalOnly );
TQToolTip::add( urlRequester,
diff --git a/kooka/kookarc b/kooka/kookarc
index a604a280..13875fff 100644
--- a/kooka/kookarc
+++ b/kooka/kookarc
@@ -2,17 +2,17 @@
Kookas MainDock,Preview ,Thumbs:first_name=Kookas MainDock,Preview\s
Kookas MainDock,Preview ,Thumbs:last_name=Thumbs
Kookas MainDock,Preview ,Thumbs:orientation=0
-Kookas MainDock,Preview ,Thumbs:tqparent=yes
+Kookas MainDock,Preview ,Thumbs:parent=yes
Kookas MainDock,Preview ,Thumbs:sepPos=72
Kookas MainDock,Preview ,Thumbs:stayButton=false
Kookas MainDock,Preview ,Thumbs:type=GROUP
Kookas MainDock,Preview :curTab=0
-Kookas MainDock,Preview :tqparent=yes
+Kookas MainDock,Preview :parent=yes
Kookas MainDock,Preview :stayButton=false
Kookas MainDock,Preview :tabNames=Kookas MainDock,Preview\s
Kookas MainDock,Preview :type=TAB_GROUP
Kookas MainDock,Thumbs,Preview :curTab=1
-Kookas MainDock,Thumbs,Preview :tqparent=yes
+Kookas MainDock,Thumbs,Preview :parent=yes
Kookas MainDock,Thumbs,Preview :stayButton=false
Kookas MainDock,Thumbs,Preview :tabNames=Kookas MainDock,Thumbs,Preview\s
Kookas MainDock,Thumbs,Preview :type=TAB_GROUP
@@ -20,7 +20,7 @@ Kookas MainDock,Thumbs:curTab=1
Kookas MainDock,Thumbs:first_name=Kookas MainDock
Kookas MainDock,Thumbs:last_name=Thumbs
Kookas MainDock,Thumbs:orientation=0
-Kookas MainDock,Thumbs:tqparent=yes
+Kookas MainDock,Thumbs:parent=yes
Kookas MainDock,Thumbs:sepPos=54
Kookas MainDock,Thumbs:stayButton=false
Kookas MainDock,Thumbs:tabNames=Kookas MainDock,Thumbs
@@ -35,28 +35,28 @@ NameList=Kookas MainDock,Thumbs,Scanpackager,Recent,Scan Parameter,Preview ,Kook
Preview ,Scanpackager,Recent,Scan Parameter,Kookas MainDock,Thumbs:first_name=Preview ,Scanpackager,Recent,Scan Parameter
Preview ,Scanpackager,Recent,Scan Parameter,Kookas MainDock,Thumbs:last_name=Kookas MainDock,Thumbs
Preview ,Scanpackager,Recent,Scan Parameter,Kookas MainDock,Thumbs:orientation=1
-Preview ,Scanpackager,Recent,Scan Parameter,Kookas MainDock,Thumbs:tqparent=yes
+Preview ,Scanpackager,Recent,Scan Parameter,Kookas MainDock,Thumbs:parent=yes
Preview ,Scanpackager,Recent,Scan Parameter,Kookas MainDock,Thumbs:sepPos=38
Preview ,Scanpackager,Recent,Scan Parameter,Kookas MainDock,Thumbs:stayButton=false
Preview ,Scanpackager,Recent,Scan Parameter,Kookas MainDock,Thumbs:type=GROUP
Preview ,Scanpackager,Recent,Scan Parameter:first_name=Preview ,Scanpackager,Recent
Preview ,Scanpackager,Recent,Scan Parameter:last_name=Scan Parameter
Preview ,Scanpackager,Recent,Scan Parameter:orientation=0
-Preview ,Scanpackager,Recent,Scan Parameter:tqparent=yes
+Preview ,Scanpackager,Recent,Scan Parameter:parent=yes
Preview ,Scanpackager,Recent,Scan Parameter:sepPos=50
Preview ,Scanpackager,Recent,Scan Parameter:stayButton=false
Preview ,Scanpackager,Recent,Scan Parameter:type=GROUP
Preview ,Scanpackager,Recent:first_name=Preview ,Scanpackager
Preview ,Scanpackager,Recent:last_name=Recent
Preview ,Scanpackager,Recent:orientation=0
-Preview ,Scanpackager,Recent:tqparent=yes
+Preview ,Scanpackager,Recent:parent=yes
Preview ,Scanpackager,Recent:sepPos=84
Preview ,Scanpackager,Recent:stayButton=false
Preview ,Scanpackager,Recent:type=GROUP
Preview ,Scanpackager:first_name=Preview\s
Preview ,Scanpackager:last_name=Scanpackager
Preview ,Scanpackager:orientation=0
-Preview ,Scanpackager:tqparent=yes
+Preview ,Scanpackager:parent=yes
Preview ,Scanpackager:sepPos=50
Preview ,Scanpackager:stayButton=false
Preview ,Scanpackager:type=GROUP
@@ -65,7 +65,7 @@ Preview :type=DOCK
Recent,Scan Parameter:first_name=Recent
Recent,Scan Parameter:last_name=Scan Parameter
Recent,Scan Parameter:orientation=0
-Recent,Scan Parameter:tqparent=yes
+Recent,Scan Parameter:parent=yes
Recent,Scan Parameter:sepPos=14
Recent,Scan Parameter:stayButton=false
Recent,Scan Parameter:type=GROUP
@@ -76,40 +76,40 @@ Scan Parameter:type=DOCK
Scanpackager,Preview ,Recent,Scan Parameter,Kookas MainDock,Thumbs:first_name=Scanpackager,Preview ,Recent,Scan Parameter
Scanpackager,Preview ,Recent,Scan Parameter,Kookas MainDock,Thumbs:last_name=Kookas MainDock,Thumbs
Scanpackager,Preview ,Recent,Scan Parameter,Kookas MainDock,Thumbs:orientation=1
-Scanpackager,Preview ,Recent,Scan Parameter,Kookas MainDock,Thumbs:tqparent=yes
+Scanpackager,Preview ,Recent,Scan Parameter,Kookas MainDock,Thumbs:parent=yes
Scanpackager,Preview ,Recent,Scan Parameter,Kookas MainDock,Thumbs:sepPos=38
Scanpackager,Preview ,Recent,Scan Parameter,Kookas MainDock,Thumbs:stayButton=false
Scanpackager,Preview ,Recent,Scan Parameter,Kookas MainDock,Thumbs:type=GROUP
Scanpackager,Preview ,Recent,Scan Parameter:first_name=Scanpackager,Preview\s
Scanpackager,Preview ,Recent,Scan Parameter:last_name=Recent,Scan Parameter
Scanpackager,Preview ,Recent,Scan Parameter:orientation=0
-Scanpackager,Preview ,Recent,Scan Parameter:tqparent=yes
+Scanpackager,Preview ,Recent,Scan Parameter:parent=yes
Scanpackager,Preview ,Recent,Scan Parameter:sepPos=48
Scanpackager,Preview ,Recent,Scan Parameter:stayButton=false
Scanpackager,Preview ,Recent,Scan Parameter:type=GROUP
Scanpackager,Preview :curTab=0
-Scanpackager,Preview :tqparent=yes
+Scanpackager,Preview :parent=yes
Scanpackager,Preview :stayButton=false
Scanpackager,Preview :tabNames=Scanpackager,Preview\s
Scanpackager,Preview :type=TAB_GROUP
Scanpackager,Recent,Scan Parameter,Kookas MainDock,Preview ,Thumbs:first_name=Scanpackager,Recent,Scan Parameter
Scanpackager,Recent,Scan Parameter,Kookas MainDock,Preview ,Thumbs:last_name=Kookas MainDock,Preview ,Thumbs
Scanpackager,Recent,Scan Parameter,Kookas MainDock,Preview ,Thumbs:orientation=1
-Scanpackager,Recent,Scan Parameter,Kookas MainDock,Preview ,Thumbs:tqparent=yes
+Scanpackager,Recent,Scan Parameter,Kookas MainDock,Preview ,Thumbs:parent=yes
Scanpackager,Recent,Scan Parameter,Kookas MainDock,Preview ,Thumbs:sepPos=41
Scanpackager,Recent,Scan Parameter,Kookas MainDock,Preview ,Thumbs:stayButton=false
Scanpackager,Recent,Scan Parameter,Kookas MainDock,Preview ,Thumbs:type=GROUP
Scanpackager,Recent,Scan Parameter,Kookas MainDock,Thumbs,Preview :first_name=Scanpackager,Recent,Scan Parameter
Scanpackager,Recent,Scan Parameter,Kookas MainDock,Thumbs,Preview :last_name=Kookas MainDock,Thumbs,Preview\s
Scanpackager,Recent,Scan Parameter,Kookas MainDock,Thumbs,Preview :orientation=1
-Scanpackager,Recent,Scan Parameter,Kookas MainDock,Thumbs,Preview :tqparent=yes
+Scanpackager,Recent,Scan Parameter,Kookas MainDock,Thumbs,Preview :parent=yes
Scanpackager,Recent,Scan Parameter,Kookas MainDock,Thumbs,Preview :sepPos=38
Scanpackager,Recent,Scan Parameter,Kookas MainDock,Thumbs,Preview :stayButton=false
Scanpackager,Recent,Scan Parameter,Kookas MainDock,Thumbs,Preview :type=GROUP
Scanpackager,Recent,Scan Parameter:first_name=Scanpackager
Scanpackager,Recent,Scan Parameter:last_name=Recent,Scan Parameter
Scanpackager,Recent,Scan Parameter:orientation=0
-Scanpackager,Recent,Scan Parameter:tqparent=yes
+Scanpackager,Recent,Scan Parameter:parent=yes
Scanpackager,Recent,Scan Parameter:sepPos=42
Scanpackager,Recent,Scan Parameter:stayButton=false
Scanpackager,Recent,Scan Parameter:type=GROUP
diff --git a/kooka/kookaview.cpp b/kooka/kookaview.cpp
index 71004040..5586ee43 100644
--- a/kooka/kookaview.cpp
+++ b/kooka/kookaview.cpp
@@ -82,7 +82,7 @@
#define STARTUP_IMG_SELECTION "SelectedImageOnStartup"
-KookaView::KookaView( KParts::DockMainWindow *tqparent, const TQCString& deviceToUse)
+KookaView::KookaView( KParts::DockMainWindow *parent, const TQCString& deviceToUse)
: TQObject(),
m_ocrResultImg(0),
ocrFabric(0),
@@ -93,21 +93,21 @@ KookaView::KookaView( KParts::DockMainWindow *tqparent, const TQCString& deviceT
m_dockRecent(0),
m_dockPreview(0),
m_dockOCRText(0),
- m_mainWindow(tqparent),
+ m_mainWindow(parent),
m_ocrResEdit(0)
{
KIconLoader *loader = KGlobal::iconLoader();
scan_params = 0L;
preview_canvas = 0L;
- m_mainDock = tqparent->createDockWidget( "Kookas MainDock",
+ m_mainDock = parent->createDockWidget( "Kookas MainDock",
loader->loadIcon( "folder_image", KIcon::Small ),
0L, i18n("Image Viewer"));
m_mainDock->setEnableDocking(KDockWidget::DockNone );
m_mainDock->setDockSite( KDockWidget::DockFullSite );
- tqparent->setView( m_mainDock);
- tqparent->setMainDockWidget( m_mainDock);
+ parent->setView( m_mainDock);
+ parent->setMainDockWidget( m_mainDock);
img_canvas = new ImageCanvas( m_mainDock );
img_canvas->setMinimumSize(100,200);
@@ -121,7 +121,7 @@ KookaView::KookaView( KParts::DockMainWindow *tqparent, const TQCString& deviceT
m_mainDock->setWidget( img_canvas );
/** Thumbview **/
- m_dockThumbs = tqparent->createDockWidget( "Thumbs",
+ m_dockThumbs = parent->createDockWidget( "Thumbs",
loader->loadIcon( "thumbnail", KIcon::Small ),
0L, i18n("Thumbnails"));
m_dockThumbs->setDockSite(KDockWidget::DockFullSite );
@@ -136,7 +136,7 @@ KookaView::KookaView( KParts::DockMainWindow *tqparent, const TQCString& deviceT
/** Packager Dock **/
/* A new packager to contain the already scanned images */
- m_dockPackager = tqparent->createDockWidget( "Scanpackager",
+ m_dockPackager = parent->createDockWidget( "Scanpackager",
loader->loadIcon( "palette_color", KIcon::Small ),
0L, i18n("Gallery"));
m_dockPackager->setDockSite(KDockWidget::DockFullSite);
@@ -155,7 +155,7 @@ KookaView::KookaView( KParts::DockMainWindow *tqparent, const TQCString& deviceT
/*
* Create a Kombobox that holds the last folders visible even on the preview page
*/
- m_dockRecent = tqparent->createDockWidget( "Recent",
+ m_dockRecent = parent->createDockWidget( "Recent",
loader->loadIcon( "image", KIcon::Small ),
0L, i18n("Gallery Folders"));
@@ -184,7 +184,7 @@ KookaView::KookaView( KParts::DockMainWindow *tqparent, const TQCString& deviceT
packager, TQT_SLOT(slotSelectDirectory( const TQString& )));
/* the object from the kscan lib to handle low level scanning */
- m_dockScanParam = tqparent->createDockWidget( "Scan Parameter",
+ m_dockScanParam = parent->createDockWidget( "Scan Parameter",
loader->loadIcon( "folder", KIcon::Small ),
0L, i18n("Scan Parameter"));
//
@@ -203,7 +203,7 @@ KookaView::KookaView( KParts::DockMainWindow *tqparent, const TQCString& deviceT
* the complete scanner options dialog
* scan_params must be zero for that */
- m_dockPreview = tqparent->createDockWidget( "Preview ",
+ m_dockPreview = parent->createDockWidget( "Preview ",
loader->loadIcon( "viewmag", KIcon::Small ),
0L, i18n("Scan Preview"));
@@ -222,7 +222,7 @@ KookaView::KookaView( KParts::DockMainWindow *tqparent, const TQCString& deviceT
/* Create a text editor part for ocr results */
- m_dockOCRText = tqparent->createDockWidget( "OCRResults",
+ m_dockOCRText = parent->createDockWidget( "OCRResults",
loader->loadIcon("edit", KIcon::Small ),
0L, i18n("OCR Result Text"));
// m_textEdit
@@ -876,7 +876,7 @@ void KookaView::slShowThumbnails(KFileTreeViewItem *dirKfi, bool forceRedraw )
}
else
{
- kftvi = static_cast<KFileTreeViewItem*>(static_cast<TQListViewItem*>(kftvi)->tqparent());
+ kftvi = static_cast<KFileTreeViewItem*>(static_cast<TQListViewItem*>(kftvi)->parent());
dirKfi = kftvi;
forceRedraw = true;
packager->setSelected( static_cast<TQListViewItem*>(dirKfi), true );
diff --git a/kooka/kookaview.h b/kooka/kookaview.h
index 21d5509a..76910cdc 100644
--- a/kooka/kookaview.h
+++ b/kooka/kookaview.h
@@ -77,7 +77,7 @@ public:
/**
* Default constructor
*/
- KookaView(KParts::DockMainWindow *tqparent, const TQCString& deviceToUse);
+ KookaView(KParts::DockMainWindow *parent, const TQCString& deviceToUse);
/**
* Destructor
diff --git a/kooka/ksaneocr.cpp b/kooka/ksaneocr.cpp
index 83ef30da..67d0aaca 100644
--- a/kooka/ksaneocr.cpp
+++ b/kooka/ksaneocr.cpp
@@ -183,26 +183,26 @@ void KSANEOCR::slLineBox( const TQRect& )
* starts visual ocr process. Depending on the ocr engine, this function creates
* a new dialog, and shows it.
*/
-bool KSANEOCR::startOCRVisible( TQWidget *tqparent )
+bool KSANEOCR::startOCRVisible( TQWidget *parent )
{
if( visibleOCRRunning ) return( false );
bool res = true;
- m_parent = tqparent;
+ m_parent = parent;
if( m_ocrEngine == GOCR )
{
- m_ocrProcessDia = new KGOCRDialog ( tqparent, m_spellInitialConfig );
+ m_ocrProcessDia = new KGOCRDialog ( parent, m_spellInitialConfig );
}
else if( m_ocrEngine == OCRAD )
{
- m_ocrProcessDia = new ocradDialog( tqparent, m_spellInitialConfig );
+ m_ocrProcessDia = new ocradDialog( parent, m_spellInitialConfig );
}
else if( m_ocrEngine == KADMOS )
{
#ifdef HAVE_KADMOS
/*** Kadmos Engine OCR ***/
- m_ocrProcessDia = new KadmosDialog( tqparent, m_spellInitialConfig );
+ m_ocrProcessDia = new KadmosDialog( parent, m_spellInitialConfig );
#else
KMessageBox::sorry(0, i18n("This version of Kooka was not compiled with KADMOS support.\n"
"Please select another OCR engine in Kooka's options dialog."));
diff --git a/kooka/ksaneocr.h b/kooka/ksaneocr.h
index 670c410b..bc2bc844 100644
--- a/kooka/ksaneocr.h
+++ b/kooka/ksaneocr.h
@@ -82,7 +82,7 @@ public:
KSANEOCR( TQWidget*, KConfig *);
~KSANEOCR();
- bool startOCRVisible( TQWidget* tqparent=0);
+ bool startOCRVisible( TQWidget* parent=0);
void finishedOCRVisible( bool );
diff --git a/kooka/ocrresedit.cpp b/kooka/ocrresedit.cpp
index 26785b4c..f8e8f2c2 100644
--- a/kooka/ocrresedit.cpp
+++ b/kooka/ocrresedit.cpp
@@ -36,8 +36,8 @@
/* -------------------- ocrResEdit -------------------- */
-ocrResEdit::ocrResEdit( TQWidget *tqparent )
- : TQTextEdit(tqparent)
+ocrResEdit::ocrResEdit( TQWidget *parent )
+ : TQTextEdit(parent)
{
m_updateColor.setNamedColor( "SeaGreen");
m_ignoreColor.setNamedColor( "CadetBlue4" );
diff --git a/kooka/ocrresedit.h b/kooka/ocrresedit.h
index f7e40dca..72517f4b 100644
--- a/kooka/ocrresedit.h
+++ b/kooka/ocrresedit.h
@@ -38,7 +38,7 @@ class ocrResEdit : public TQTextEdit
Q_OBJECT
TQ_OBJECT
public:
- ocrResEdit( TQWidget *tqparent );
+ ocrResEdit( TQWidget *parent );
public slots:
void slUpdateOCRResult( int line, const TQString& wordFrom,
diff --git a/kooka/scanpackager.cpp b/kooka/scanpackager.cpp
index fbda481f..9a8c9d3a 100644
--- a/kooka/scanpackager.cpp
+++ b/kooka/scanpackager.cpp
@@ -71,7 +71,7 @@
/* ----------------------------------------------------------------------- */
/* Constructor Scan Packager */
-ScanPackager::ScanPackager( TQWidget *tqparent ) : KFileTreeView( tqparent )
+ScanPackager::ScanPackager( TQWidget *parent ) : KFileTreeView( parent )
{
// TODO:
setItemsRenameable (true );
@@ -531,7 +531,7 @@ void ScanPackager::slClicked( TQListViewItem *newItem )
}
else
{
- emit( showThumbnails( static_cast<KFileTreeViewItem*>(item->tqparent())));
+ emit( showThumbnails( static_cast<KFileTreeViewItem*>(item->parent())));
}
}
else
@@ -854,7 +854,7 @@ void ScanPackager::slAddImage( TQImage *img, KookaImageMeta* )
TQString s;
/* Count amount of tqchildren of the father */
- TQListViewItem *paps = curr->tqparent();
+ TQListViewItem *paps = curr->parent();
if( curr->isDir() ) /* take only father if the is no directory */
paps = curr;
@@ -1012,7 +1012,7 @@ void ScanPackager::slotImportFile()
if( ! curr->isDir() )
{
- KFileTreeViewItem *pa = static_cast<KFileTreeViewItem*>(curr->tqparent());
+ KFileTreeViewItem *pa = static_cast<KFileTreeViewItem*>(curr->parent());
impTarget = pa->url();
}
kdDebug(28000) << "Importing to " << impTarget.url() << endl;
@@ -1239,12 +1239,12 @@ void ScanPackager::contentsDragMoveEvent( TQDragMoveEvent *e )
}
TQListViewItem *afterme = 0;
- TQListViewItem *tqparent = 0;
+ TQListViewItem *parent = 0;
- findDrop( e->pos(), tqparent, afterme );
+ findDrop( e->pos(), parent, afterme );
// "afterme" is 0 when aiming at a directory itself
- TQListViewItem *item = afterme ? afterme : tqparent;
+ TQListViewItem *item = afterme ? afterme : parent;
if( item )
{
diff --git a/kooka/scanpackager.h b/kooka/scanpackager.h
index c50c4d56..ab4519e6 100644
--- a/kooka/scanpackager.h
+++ b/kooka/scanpackager.h
@@ -76,7 +76,7 @@ class ScanPackager : public KFileTreeView
Q_OBJECT
TQ_OBJECT
public:
- ScanPackager( TQWidget *tqparent);
+ ScanPackager( TQWidget *parent);
~ScanPackager();
virtual TQString getImgName( TQString name_on_disk );
@@ -143,7 +143,7 @@ private:
KFileTreeViewItem *spFindItem( SearchType type, const TQString name, const KFileTreeBranch* branch = 0 );
TQString itemDirectory( const KFileTreeViewItem*, bool relativ = false ) const;
- // int readDir( TQListViewItem *tqparent, TQString dir_to_read );
+ // int readDir( TQListViewItem *parent, TQString dir_to_read );
void showContextMenu( TQPoint p, bool show_folder = true );
TQString m_currImportDir;
diff --git a/kooka/thumbview.h b/kooka/thumbview.h
index 52b2bf05..49df9056 100644
--- a/kooka/thumbview.h
+++ b/kooka/thumbview.h
@@ -63,7 +63,7 @@ class ThumbView: public TQVBox /* KIconView */
public:
- ThumbView( TQWidget *tqparent, const char *name=0 );
+ ThumbView( TQWidget *parent, const char *name=0 );
~ThumbView();
void setCurrentDir( const KURL& s)
diff --git a/kooka/thumbviewitem.cpp b/kooka/thumbviewitem.cpp
index fe62e7e8..e682c34b 100644
--- a/kooka/thumbviewitem.cpp
+++ b/kooka/thumbviewitem.cpp
@@ -32,10 +32,10 @@
#include "thumbview.h"
#include "thumbviewitem.h"
-ThumbViewItem::ThumbViewItem(TQIconView *tqparent, const TQString &text,
+ThumbViewItem::ThumbViewItem(TQIconView *parent, const TQString &text,
const TQPixmap &pixmap,
KFileItem *fi )
- :KFileIconViewItem( tqparent, text, pixmap,fi )
+ :KFileIconViewItem( parent, text, pixmap,fi )
{
}
diff --git a/kooka/thumbviewitem.h b/kooka/thumbviewitem.h
index 5bf829dd..4478df34 100644
--- a/kooka/thumbviewitem.h
+++ b/kooka/thumbviewitem.h
@@ -41,7 +41,7 @@ class KFileTreeViewItem;
class ThumbViewItem: public KFileIconViewItem
{
public:
- ThumbViewItem( TQIconView *tqparent,
+ ThumbViewItem( TQIconView *parent,
const TQString &text,
const TQPixmap &pixmap,
KFileItem *fi );
diff --git a/kooka/img_saver.cpp b/kooka/img_saver.cpp
index e0bf399d..847023d1 100644
--- a/kooka/img_saver.cpp
+++ b/kooka/img_saver.cpp
@@ -58,8 +58,8 @@
#include "previewer.h"
#include "kookaimage.h"
-FormatDialog::FormatDialog( TQWidget *tqparent, const TQString&, const char *name )
- :KDialogBase( tqparent, name, true,
+FormatDialog::FormatDialog( TQWidget *parent, const TQString&, const char *name )
+ :KDialogBase( parent, name, true,
/* Tabbed,*/ i18n( "Kooka Save Assistant" ),
Ok|Cancel, Ok )
@@ -218,8 +218,8 @@ void FormatDialog::buildHelp( void )
/* ********************************************************************** */
-ImgSaver::ImgSaver( TQWidget *tqparent, const KURL dir_name )
- : TQObject( tqparent )
+ImgSaver::ImgSaver( TQWidget *parent, const KURL dir_name )
+ : TQObject( parent )
{
if( dir_name.isEmpty() || dir_name.protocol() != "file" )
@@ -250,8 +250,8 @@ ImgSaver::ImgSaver( TQWidget *tqparent, const KURL dir_name )
}
-ImgSaver::ImgSaver( TQWidget *tqparent )
- :TQObject( tqparent )
+ImgSaver::ImgSaver( TQWidget *parent )
+ :TQObject( parent )
{
directory = Previewer::galleryRoot();
createDir( directory );
@@ -395,7 +395,7 @@ TQString ImgSaver::createFilename( TQString format )
}
/**
* This function gets a filename from the tqparent. The filename must not be relative.
**/
ImgSaveStat ImgSaver::saveImage( TQImage *image, const KURL& filename, const TQString& imgFormat )
{
@@ -395,7 +395,7 @@ TQString ImgSaver::createFilename( TQString format )
}
/**
- * This function gets a filename from the tqparent. The filename must not be relative.
+ * This function gets a filename from the parent. The filename must not be relative.
**/
ImgSaveStat ImgSaver::saveImage( TQImage *image, const KURL& filename, const TQString& imgFormat )
diff --git a/kooka/thumbview.cpp b/kooka/thumbview.cpp
index 60312bad..a431f1ea 100644
--- a/kooka/thumbview.cpp
+++ b/kooka/thumbview.cpp
@@ -47,8 +47,8 @@
-ThumbView::ThumbView( TQWidget *tqparent, const char *name )
- : TQVBox( tqparent ),
+ThumbView::ThumbView( TQWidget *parent, const char *name )
+ : TQVBox( parent ),
m_iconView(0),
m_job(0)
{
@@ -238,7 +238,7 @@ void ThumbView::slCheckForUpdate( KFileItem *kfit )
bool haveItem = false;
/* iterate over all icon items and compare urls.
* TODO: Check the tqparent url to avoid iteration over all */
for ( TQIconViewItem *item = m_iconView->firstItem(); item && !haveItem;
item = item->nextItem() )
{
@@ -269,7 +269,7 @@ bool ThumbView::deleteImage( KFileItem *kfit )
bool haveItem = false;
/* iterate over all icon items and compare urls.
* TODO: Check the tqparent url to avoid iteration over all */
for ( TQIconViewItem *item = m_iconView->firstItem(); item && !haveItem; item = item->nextItem() )
{
if( searchUrl == static_cast<ThumbViewItem*>(item)->itemUrl() )
@@ -238,7 +238,7 @@ void ThumbView::slCheckForUpdate( KFileItem *kfit )
bool haveItem = false;
/* iterate over all icon items and compare urls.
- * TODO: Check the tqparent url to avoid iteration over all */
+ * TODO: Check the parent url to avoid iteration over all */
for ( TQIconViewItem *item = m_iconView->firstItem(); item && !haveItem;
item = item->nextItem() )
@@ -269,7 +269,7 @@ bool ThumbView::deleteImage( KFileItem *kfit )
bool haveItem = false;
/* iterate over all icon items and compare urls.
- * TODO: Check the tqparent url to avoid iteration over all */
+ * TODO: Check the parent url to avoid iteration over all */
for ( TQIconViewItem *item = m_iconView->firstItem(); item && !haveItem; item = item->nextItem() )
{